// src/components/Navbar.js
"use client"; // Mark this as a Client Component

import { FaSearch, FaBars, FaBell, FaUserCircle, FaCog, FaMoon, FaSun } from "react-icons/fa";
import { useState, useEffect, useRef, useContext } from "react";
import { useRouter } from "next/navigation"; // Updated import for App Router
import { ThemeContext } from "../context/ThemeContext";
import { account } from "../lib/appwrite"; // Import AppWrite account instance
import { useAuth } from "../context/AuthContext"; // Import useAuth
import { Bell } from "lucide-react";
import { motion } from "framer-motion";

const Navbar = () => {
  const [activeTab, setActiveTab] = useState("Dashboard");
  const [dropdownOpen, setDropdownOpen] = useState(false);
  const { darkMode, toggleDarkMode } = useContext(ThemeContext);
  const [currentUser, setCurrentUser] = useState(null);
  const router = useRouter(); // Updated usage
  const dropdownRef = useRef(null);
  const { setIsAuthenticated } = useAuth(); // Get setIsAuthenticated from context

  // Fetch the logged-in user from AppWrite
  useEffect(() => {
    const fetchUser = async () => {
      try {
        const user = await account.get(); // Get the logged-in user
        setCurrentUser(user);
      } catch (error) {
        console.error("User not authenticated:", error);
        router.push("/signup"); // Redirect to signup if not logged in
      }
    };
    fetchUser();
  }, [router]);

  // Apply theme on mount
  useEffect(() => {
    if (darkMode) {
      document.documentElement.classList.add("dark"); // Apply dark mode globally
      localStorage.setItem("theme", "dark");
    } else {
      document.documentElement.classList.remove("dark");
      localStorage.setItem("theme", "light");
    }
  }, [darkMode]);

  

  const toggleDropdown = () => {
    setDropdownOpen(!dropdownOpen);
  };

  useEffect(() => {
    function handleClickOutside(event) {
      if (dropdownRef.current && !dropdownRef.current.contains(event.target)) {
        setDropdownOpen(false);
      }
    }
    document.addEventListener("mousedown", handleClickOutside);
    return () => {
      document.removeEventListener("mousedown", handleClickOutside);
    };
  }, []);

  const handleSignOut = async () => {
    try {
      await account.deleteSession("current"); // Logout the user from AppWrite
      setCurrentUser(null);
      setIsAuthenticated(false); // Update authentication state
      router.push("/signup"); // Redirect to signup page
    } catch (error) {
      console.error("Logout failed:", error);
    }
  };

  return (
<nav className="bg-white dark:bg-gray-900 shadow-md sticky top-0 w-full z-50 p-4 flex items-center justify-between">
{/* Left Side: Hamburger & Search Box */}
      <div className="flex items-center">
        {/* Hamburger Icon */}
        <button className="p-2 border border-gray-300 rounded-md hover:bg-gray-100 dark:hover:bg-gray-700">
          <FaBars className="text-gray-500 dark:text-gray-300 text-lg" />
        </button>

        {/* Search Box */}
        <div className="flex items-center gap-[2px] border border-gray-300 bg-white dark:bg-gray-800 p-2 rounded h-[45px] w-[400px] ml-2">
          {/* Search Bar */}
          <div className="relative flex-1">
            <FaSearch className="absolute left-3 top-1/2 transform -translate-y-1/2 text-gray-400" />
            <input
              type="text"
              placeholder="Search or type command..."
              className="w-full bg-transparent border-none pl-10 pr-10 py-2 focus:outline-none text-gray-800 dark:text-gray-200"
            />
          </div>

          {/* Shortcut Key Indicator */}
          <div className="px-2 py-1 bg-gray-100 dark:bg-gray-700 text-gray-500 dark:text-gray-300 text-xs rounded-md">
            ⌘K
          </div>
        </div>
      </div>

      {/* Right Side: Icons & User Section */}
      <div className="flex items-center gap-4">
        {/* Dark Mode Toggle */}
        <button
          onClick={toggleDarkMode}
          className="p-2 rounded-full border-2 border-gray-300 flex items-center justify-center w-10 h-10 transition duration-300"
        >
          {darkMode ? (
            // <FaSun className="text-yellow-400 text-xl" />
            <svg
              width="20"
              height="20"
              viewBox="0 0 20 20"
              fill="none"
              xmlns="http://www.w3.org/2000/svg"
            >
              <path
                fillRule="evenodd"
                clipRule="evenodd"
                d="M9.99998 1.5415C10.4142 1.5415 10.75 1.87729 10.75 2.2915V3.5415C10.75 3.95572 10.4142 4.2915 9.99998 4.2915C9.58577 4.2915 9.24998 3.95572 9.24998 3.5415V2.2915C9.24998 1.87729 9.58577 1.5415 9.99998 1.5415ZM10.0009 6.79327C8.22978 6.79327 6.79402 8.22904 6.79402 10.0001C6.79402 11.7712 8.22978 13.207 10.0009 13.207C11.772 13.207 13.2078 11.7712 13.2078 10.0001C13.2078 8.22904 11.772 6.79327 10.0009 6.79327ZM5.29402 10.0001C5.29402 7.40061 7.40135 5.29327 10.0009 5.29327C12.6004 5.29327 14.7078 7.40061 14.7078 10.0001C14.7078 12.5997 12.6004 14.707 10.0009 14.707C7.40135 14.707 5.29402 12.5997 5.29402 10.0001ZM15.9813 5.08035C16.2742 4.78746 16.2742 4.31258 15.9813 4.01969C15.6884 3.7268 15.2135 3.7268 14.9207 4.01969L14.0368 4.90357C13.7439 5.19647 13.7439 5.67134 14.0368 5.96423C14.3297 6.25713 14.8045 6.25713 15.0974 5.96423L15.9813 5.08035ZM18.4577 10.0001C18.4577 10.4143 18.1219 10.7501 17.7077 10.7501H16.4577C16.0435 10.7501 15.7077 10.4143 15.7077 10.0001C15.7077 9.58592 16.0435 9.25013 16.4577 9.25013H17.7077C18.1219 9.25013 18.4577 9.58592 18.4577 10.0001ZM14.9207 15.9806C15.2135 16.2735 15.6884 16.2735 15.9813 15.9806C16.2742 15.6877 16.2742 15.2128 15.9813 14.9199L15.0974 14.036C14.8045 13.7431 14.3297 13.7431 14.0368 14.036C13.7439 14.3289 13.7439 14.8038 14.0368 15.0967L14.9207 15.9806ZM9.99998 15.7088C10.4142 15.7088 10.75 16.0445 10.75 16.4588V17.7088C10.75 18.123 10.4142 18.4588 9.99998 18.4588C9.58577 18.4588 9.24998 18.123 9.24998 17.7088V16.4588C9.24998 16.0445 9.58577 15.7088 9.99998 15.7088ZM5.96356 15.0972C6.25646 14.8043 6.25646 14.3295 5.96356 14.0366C5.67067 13.7437 5.1958 13.7437 4.9029 14.0366L4.01902 14.9204C3.72613 15.2133 3.72613 15.6882 4.01902 15.9811C4.31191 16.274 4.78679 16.274 5.07968 15.9811L5.96356 15.0972ZM4.29224 10.0001C4.29224 10.4143 3.95645 10.7501 3.54224 10.7501H2.29224C1.87802 10.7501 1.54224 10.4143 1.54224 10.0001C1.54224 9.58592 1.87802 9.25013 2.29224 9.25013H3.54224C3.95645 9.25013 4.29224 9.58592 4.29224 10.0001ZM4.9029 5.9637C5.1958 6.25659 5.67067 6.25659 5.96356 5.9637C6.25646 5.6708 6.25646 5.19593 5.96356 4.90303L5.07968 4.01915C4.78679 3.72626 4.31191 3.72626 4.01902 4.01915C3.72613 4.31204 3.72613 4.78692 4.01902 5.07981L4.9029 5.9637Z"
                fill="currentColor"
              />
            </svg>
          ) : (
            // <FaMoon className="text-gray-600 text-xl" />
            <svg
              className="dark:hidden"
              width="20"
              height="20"
              viewBox="0 0 20 20"
              fill="none"
              xmlns="http://www.w3.org/2000/svg"
            >
              <path
                d="M17.4547 11.97L18.1799 12.1611C18.265 11.8383 18.1265 11.4982 17.8401 11.3266C17.5538 11.1551 17.1885 11.1934 16.944 11.4207L17.4547 11.97ZM8.0306 2.5459L8.57989 3.05657C8.80718 2.81209 8.84554 2.44682 8.67398 2.16046C8.50243 1.8741 8.16227 1.73559 7.83948 1.82066L8.0306 2.5459ZM12.9154 13.0035C9.64678 13.0035 6.99707 10.3538 6.99707 7.08524H5.49707C5.49707 11.1823 8.81835 14.5035 12.9154 14.5035V13.0035ZM16.944 11.4207C15.8869 12.4035 14.4721 13.0035 12.9154 13.0035V14.5035C14.8657 14.5035 16.6418 13.7499 17.9654 12.5193L16.944 11.4207ZM16.7295 11.7789C15.9437 14.7607 13.2277 16.9586 10.0003 16.9586V18.4586C13.9257 18.4586 17.2249 15.7853 18.1799 12.1611L16.7295 11.7789ZM10.0003 16.9586C6.15734 16.9586 3.04199 13.8433 3.04199 10.0003H1.54199C1.54199 14.6717 5.32892 18.4586 10.0003 18.4586V16.9586ZM3.04199 10.0003C3.04199 6.77289 5.23988 4.05695 8.22173 3.27114L7.83948 1.82066C4.21532 2.77574 1.54199 6.07486 1.54199 10.0003H3.04199ZM6.99707 7.08524C6.99707 5.52854 7.5971 4.11366 8.57989 3.05657L7.48132 2.03522C6.25073 3.35885 5.49707 5.13487 5.49707 7.08524H6.99707Z"
                fill="currentColor"
              />
            </svg>
          )}
        </button>


        {/* Notifications & Settings */}
        <div className="relative w-11 h-11 flex items-center justify-center rounded-full border border-gray-300">
          <Bell className="text-gray-600 w-6 h-6" />
          <motion.div
            className="absolute top-1 right-1 w-3 h-3 bg-orange-500 rounded-full"
            animate={{
              scale: [1, 1.4, 1],
              opacity: [1, 0.6, 1],
            }}
            transition={{
              duration: 1,
              repeat: Infinity,
              ease: "easeInOut",
            }}
          />
        </div>
        {/* ---setting icon--- */}
        {/* <FaCog className="text-gray-600 dark:text-gray-300 text-xl cursor-pointer hover:text-blue-500" /> */}
        {/* --------------------------------------------------------------- */}

        {/* User Profile Dropdown */}
        <div className="relative" ref={dropdownRef}>
          <div
            className="flex items-center gap-2 cursor-pointer hover:text-blue-500"
            onClick={toggleDropdown}
          >

            {/* profile icon */}
            {/* <FaUserCircle className="text-gray-600 dark:text-gray-300 text-2xl" /> */}
            <img src="/images/user/owner.jpg" alt="Owner" width={40} height={40} className="rounded-full" />
            <div className="flex items-center gap-2 cursor-pointer hover:text-blue-500">
          {currentUser?.name || "user name"}
          </div>
          </div>
          
          {/* Dropdown Menu */}
          {dropdownOpen && currentUser && (
            <div className="absolute right-0 mt-2 w-48 bg-white dark:bg-gray-800 border rounded-md shadow-lg p-3 transition-opacity duration-300 z-50">
              <h3 className="font-semibold text-gray-800 dark:text-gray-200">
                {currentUser.name || "User"}
              </h3>
              <p className="text-sm text-gray-500 dark:text-gray-400">
                {currentUser.email}
              </p>
              <hr className="my-2 border-gray-300 dark:border-gray-600" />
              <button
                onClick={handleSignOut}
                className="block w-full text-left text-sm text-red-500 dark:text-red-400 hover:bg-gray-100 dark:hover:bg-gray-700 p-2 rounded-md"
              >
                Sign Out
              </button>
            </div>
            
          )}
        </div>
       
      </div>
    </nav>
  );


};

export default Navbar;