"use client";
import React, { useState, useEffect } from "react";
import { Bar } from "react-chartjs-2";
import { Chart as ChartJS, CategoryScale, LinearScale, BarElement, Title, Tooltip, Legend } from "chart.js";

// Register Chart.js components
ChartJS.register(CategoryScale, LinearScale, BarElement, Title, Tooltip, Legend);

const Reports = () => {
    const [deviceData, setDeviceData] = useState(null);
    const [browserData, setBrowserData] = useState(null);
    const [osData, setOsData] = useState(null);
    const [loading, setLoading] = useState(true);
    const [error, setError] = useState(null);
    const [selectedFields, setSelectedFields] = useState({
        device: true,
        os: true,
        browser: true,
    });

    // Fetch Data
    const fetchData = async (endpoint, setDataFunction) => {
        try {
            const response = await fetch(`/api/proxy?domain=meerafirms.in&endpoint=${endpoint}`);
            if (!response.ok) {
                const errorData = await response.json();
                throw new Error(errorData.error || `HTTP Error: ${response.status}`);
            }
            const result = await response.json();
            setDataFunction(result);
            console.log(`${endpoint} Data:`, result);
        } catch (err) {
            console.error(`Error fetching ${endpoint}:`, err);
            setError(err.message);
        }
    };

    useEffect(() => {
        const fetchAllData = async () => {
            setLoading(true);
            await Promise.all([
                fetchData("visits/total-visits?fields=device", setDeviceData),
                fetchData("visits/total-visits?fields=os", setOsData),
                fetchData("visits/total-visits?fields=browser", setBrowserData),
            ]);
            setLoading(false);
        };

        fetchAllData();
    }, []);

    // Handle Checkbox Changes
    const handleCheckboxChange = (field) => {
        setSelectedFields((prevFields) => ({
            ...prevFields,
            [field]: !prevFields[field],
        }));
    };

    // Function to Download Report as CSV
    const downloadCSV = () => {
        let csvContent = "data:text/csv;charset=utf-8,";
        csvContent += "Category,Type,Visits\n";

        if (selectedFields.device && deviceData) {
            Object.entries(deviceData.Devices || {}).forEach(([key, value]) => {
                csvContent += `Device,${key},${value}\n`;
            });
        }

        if (selectedFields.os && osData) {
            Object.entries(osData.OS || {}).forEach(([key, value]) => {
                csvContent += `OS,${key},${value}\n`;
            });
        }

        if (selectedFields.browser && browserData) {
            Object.entries(browserData.Browsers || {}).forEach(([key, value]) => {
                csvContent += `Browser,${key},${value}\n`;
            });
        }

        const encodedUri = encodeURI(csvContent);
        const link = document.createElement("a");
        link.setAttribute("href", encodedUri);
        link.setAttribute("download", "website_report.csv");
        document.body.appendChild(link);
        link.click();
        document.body.removeChild(link);
    };

    // Chart Data (Only for selected fields)
    const chartData = {
        labels: [],
        datasets: [
            {
                label: "Website Metrics",
                data: [],
                backgroundColor: [],
                borderColor: [],
                borderWidth: 1,
            },
        ],
    };

    if (selectedFields.device && deviceData) {
        Object.entries(deviceData.Devices || {}).forEach(([key, value]) => {
            chartData.labels.push(`Device: ${key}`);
            chartData.datasets[0].data.push(value);
            chartData.datasets[0].backgroundColor.push("#3498db");
            chartData.datasets[0].borderColor.push("#2980b9");
        });
    }

    if (selectedFields.os && osData) {
        Object.entries(osData.OS || {}).forEach(([key, value]) => {
            chartData.labels.push(`OS: ${key}`);
            chartData.datasets[0].data.push(value);
            chartData.datasets[0].backgroundColor.push("#2ecc71");
            chartData.datasets[0].borderColor.push("#27ae60");
        });
    }

    if (selectedFields.browser && browserData) {
        Object.entries(browserData.Browsers || {}).forEach(([key, value]) => {
            chartData.labels.push(`Browser: ${key}`);
            chartData.datasets[0].data.push(value);
            chartData.datasets[0].backgroundColor.push("#f39c12");
            chartData.datasets[0].borderColor.push("#e67e22");
        });
    }

    const chartOptions = {
        responsive: true,
        maintainAspectRatio: false,
        scales: {
            y: {
                beginAtZero: true,
            },
        },
    };

    return (
        <div className="p-4 w-[500px] bg-white shadow-md rounded-lg">
            <h2 className="text-lg font-bold mb-2">Generate Report</h2>

            {loading && <p>Loading...</p>}
            {error && <p className="text-red-500">Error: {error}</p>}

            {/* Checkboxes to Select Data Fields */}
            <div className="mb-4">
                <label className="flex items-center space-x-2">
                    <input
                        type="checkbox"
                        checked={selectedFields.device}
                        onChange={() => handleCheckboxChange("device")}
                    />
                    <span>Device</span>
                </label>
                <label className="flex items-center space-x-2">
                    <input
                        type="checkbox"
                        checked={selectedFields.os}
                        onChange={() => handleCheckboxChange("os")}
                    />
                    <span>OS</span>
                </label>
                <label className="flex items-center space-x-2">
                    <input
                        type="checkbox"
                        checked={selectedFields.browser}
                        onChange={() => handleCheckboxChange("browser")}
                    />
                    <span>Browser</span>
                </label>
            </div>

           

            {/* Bar Chart */}
            <div className="w-full h-64 mt-4">
                <Bar data={chartData} options={chartOptions} />
            </div>

            <button
                className="mt-4 px-4 py-2 bg-blue-500 text-white rounded  hover:bg-blue-400"
                onClick={downloadCSV}
            >
                Generate Report (CSV)
            </button>
        </div>
    );
};

export default Reports;
