// src/app/signup/page.js
"use client"; // Mark as Client Component

import { useState, useEffect } from "react";
import { useRouter } from "next/navigation"; // Next.js navigation
import { account, ID } from "../lib/appwrite";
import PhoneInput from "react-phone-input-2"; // Import PhoneInput
import "react-phone-input-2/lib/style.css"; // Import styles
import { useAuth } from "../context/AuthContext"; // Import useAuth

export default function AuthForm() {
  const [firstName, setFirstName] = useState("");
  const [lastName, setLastName] = useState("");
  const [phone, setPhone] = useState("");
  const [email, setEmail] = useState("");
  const [password, setPassword] = useState("");
  const [loading, setLoading] = useState(false);
  const [isLogin, setIsLogin] = useState(true);
  const router = useRouter(); // Next.js router
  const { setIsAuthenticated } = useAuth(); // Get setIsAuthenticated from context

  useEffect(() => {
    const checkAuth = async () => {
      try {
        const user = await account.get();
        if (user) {
          localStorage.setItem("isLoggedIn", true);
          router.push("/dashboard"); // Use Next.js router
        }
      } catch (error) {
        console.warn("No active session:", error);
        localStorage.removeItem("isLoggedIn");
      }
    };
    checkAuth();
  }, [router]);

  const handleAuth = async (e) => {
    e.preventDefault();
    setLoading(true);
    try {
      if (isLogin) {
        await account.createEmailPasswordSession(email, password);
        alert("Login successful!");
        const user = await account.get();
        if (user) {
          localStorage.setItem("isLoggedIn", true);
          setIsAuthenticated(true); // Use setIsAuthenticated from context
          router.push("/dashboard"); // Use Next.js router
        }
      } else {
        const user = await account.create(ID.unique(), email, password, `${firstName} ${lastName}`);
        console.log("User created:", user);
        alert("Signup successful! Please log in.");
        setIsLogin(true);
      }
    } catch (error) {
      console.error("Auth error:", error);
      alert(`Authentication failed: ${error.message}`);
    } finally {
      setLoading(false);
    }
  };

  return (
    <div className="grid grid-cols-2 min-h-screen bg-gray-100">
      {/* Left Side - Auth Form */}
      <div className="flex flex-col justify-center items-center p-10 bg-white shadow-lg">
        <h2 className="text-3xl font-bold text-gray-800 text-left">
          {isLogin ? "Login to your account" : "Sign up now"}
        </h2>
        <form onSubmit={handleAuth} className="mt-6 space-y-6 w-full max-w-md">
          {!isLogin && (
            <div className="flex gap-5">
              <input
                type="text"
                placeholder="First name"
                className="border p-3 rounded-md w-1/2"
                value={firstName}
                onChange={(e) => setFirstName(e.target.value)}
                required={!isLogin}
                disabled={loading}
              />
              <input
                type="text"
                placeholder="Last name"
                className="border p-3 rounded-md w-1/2"
                value={lastName}
                onChange={(e) => setLastName(e.target.value)}
                required={!isLogin}
                disabled={loading}
              />
            </div>
          )}
          <PhoneInput
            country={"us"}
            value={phone}
            onChange={setPhone}
            inputProps={{ required: !isLogin, disabled: loading, className: "border p-3 pl-10 rounded-md w-full" }}
          />
          <input
            type="email"
            placeholder="Email address"
            className="border p-3 rounded-md w-full"
            value={email}
            onChange={(e) => setEmail(e.target.value)}
            required
            disabled={loading}
          />
          <input
            type="password"
            placeholder="Password"
            className="border p-3 rounded-md w-full"
            value={password}
            onChange={(e) => setPassword(e.target.value)}
            required
            disabled={loading}
          />
          <button
            type="submit"
            className="w-full bg-yellow-500 text-black font-semibold p-3 rounded-md hover:bg-yellow-600"
            disabled={loading}
          >
            {loading ? (isLogin ? "Logging in..." : "Signing up...") : (isLogin ? "Login" : "Sign up")}
          </button>
        </form>
        <p className="text-sm text-gray-600 text-center mt-4">
          {isLogin ? "Don't have an account?" : "Already have an account?"}
          <button className="text-blue-500 ml-1" onClick={() => setIsLogin(!isLogin)} disabled={loading}>
            {isLogin ? "Sign up" : "Log in"}
          </button>
        </p>
      </div>
      {/* Right Side - Image and Branding */}
      <div className="flex flex-col justify-center items-center bg-[#161950] relative h-screen overflow-hidden">
        {/* Logo & Text */}
        <div className="relative z-20 flex flex-col justify-center items-center h-full text-center">
          <img width={231} height={48} src="/images/logo/auth-logo.svg" alt="Auth Logo" />
          <p className="text-gray-400 dark:text-white/60">
            Free and Open-Source Tailwind CSS Admin Dashboard Template
          </p>
        </div>
        {/* Background Shape */}
        <img
          src="/images/shape/grid-01.svg"
          alt="Background Shape"
          className="absolute top-4 right-0 w-full mix-blend-overlay z-10"
        />
      </div>
    </div>
  );
}